=======
History
=======

0.1.0 (2018-07-09)
------------------

* package created


0.2.0 (2019-08-14)
------------------

* First release on PyPI.
  

0.2.1 (2019-08-15)
------------------

*  fixed the bad urls from lazy_regression_tests to lazy-regression-tests.  Github link should work now
   
0.2.3 (2019-08-18)
------------------

*  updated README.md

0.6.0 (2020-03-03)
------------------

*  updated README.md
*  reworked architecture around FilterDirectives and ValidationDirectives, with a metaclass to provide class inheritance
*  better tests and test coverage